@@ -139,7 +139,7 @@ def _get_phaserevs(repo):
 
 def _dirty_wc(repo):
     """return true if the working directory has changes"""
-    return repo.status() != ([],)*7  # dirty working dir
+    return bool(sum(len(l) for l in repo.status())) # dirty working dir
 
 def _rev_order(phaserevs, rev):
     """return a sort key for changeset reordering (<freshness>, rev)
