@@ -394,6 +394,9 @@ class HgFileListModel(QAbstractTableModel):
     def __len__(self):
         return len(self._files)
 
+    def __contains__(self, filename):
+        return filename in self._filesdict
+
     def rowCount(self, parent=None):
         return len(self)
 
